@@ -362,7 +362,8 @@ module.exports = {
 	],
 	"72.0.3626.52": [
 		"5.0.0-beta.1",
-		"5.0.0-beta.2"
+		"5.0.0-beta.2",
+		"6.0.0-nightly.20190123"
 	],
 	"73.0.3683.27": [
 		"5.0.0-beta.3"
@@ -664,6 +665,7 @@ module.exports = {
 		"8.0.0-nightly.20190909",
 		"8.0.0-nightly.20190910",
 		"8.0.0-nightly.20190911",
+		"8.0.0-nightly.20190912",
 		"8.0.0-nightly.20190913",
 		"8.0.0-nightly.20190914",
 		"8.0.0-nightly.20190915",
@@ -674,9 +676,11 @@ module.exports = {
 		"8.0.0-nightly.20190920"
 	],
 	"79.0.3919.0": [
+		"8.0.0-nightly.20190922",
 		"8.0.0-nightly.20190923",
 		"8.0.0-nightly.20190924",
 		"8.0.0-nightly.20190926",
+		"8.0.0-nightly.20190928",
 		"8.0.0-nightly.20190929",
 		"8.0.0-nightly.20190930",
 		"8.0.0-nightly.20191001",
@@ -690,6 +694,7 @@ module.exports = {
 	],
 	"80.0.3952.0": [
 		"8.0.0-nightly.20191101",
+		"8.0.0-nightly.20191103",
 		"8.0.0-nightly.20191105"
 	],
 	"80.0.3987.86": [
@@ -747,6 +752,7 @@ module.exports = {
 		"9.0.0-beta.10"
 	],
 	"82.0.4085.14": [
+		"9.0.0-beta.11",
 		"9.0.0-beta.12",
 		"9.0.0-beta.13"
 	],
@@ -784,12 +790,15 @@ module.exports = {
 		"9.0.0-nightly.20191122",
 		"9.0.0-nightly.20191123",
 		"9.0.0-nightly.20191124",
+		"9.0.0-nightly.20191126",
+		"9.0.0-nightly.20191128",
 		"9.0.0-nightly.20191129",
 		"9.0.0-nightly.20191130",
 		"9.0.0-nightly.20191201",
 		"9.0.0-nightly.20191202",
 		"9.0.0-nightly.20191203",
 		"9.0.0-nightly.20191204",
+		"9.0.0-nightly.20191205",
 		"9.0.0-nightly.20191210"
 	],
 	"81.0.3994.0": [
@@ -1185,6 +1194,10 @@ module.exports = {
 		"12.0.0-beta.31"
 	],
 	"87.0.4268.0": [
+		"12.0.0-nightly.20201002",
+		"12.0.0-nightly.20201007",
+		"12.0.0-nightly.20201009",
+		"12.0.0-nightly.20201012",
 		"12.0.0-nightly.20201013",
 		"12.0.0-nightly.20201014",
 		"12.0.0-nightly.20201015"
@@ -1267,6 +1280,7 @@ module.exports = {
 		"13.0.0-beta.7",
 		"13.0.0-beta.8",
 		"13.0.0-beta.9",
+		"13.0.0-beta.10",
 		"13.0.0-beta.11",
 		"13.0.0-beta.12",
 		"13.0.0-beta.13",
@@ -1308,6 +1322,7 @@ module.exports = {
 	],
 	"91.0.4472.38": [
 		"13.0.0-beta.24",
+		"13.0.0-beta.25",
 		"13.0.0-beta.26",
 		"13.0.0-beta.27",
 		"13.0.0-beta.28"
@@ -1987,7 +2002,13 @@ module.exports = {
 		"19.1.0",
 		"19.1.1",
 		"19.1.2",
-		"19.1.3"
+		"19.1.3",
+		"19.1.4",
+		"19.1.5",
+		"19.1.6",
+		"19.1.7",
+		"19.1.8",
+		"19.1.9"
 	],
 	"103.0.5044.0": [
 		"20.0.0-alpha.1",
@@ -2067,7 +2088,17 @@ module.exports = {
 		"20.2.0",
 		"20.3.0",
 		"20.3.1",
-		"20.3.2"
+		"20.3.2",
+		"20.3.3",
+		"20.3.4",
+		"20.3.5",
+		"20.3.6",
+		"20.3.7",
+		"20.3.8",
+		"20.3.9",
+		"20.3.10",
+		"20.3.11",
+		"20.3.12"
 	],
 	"105.0.5187.0": [
 		"21.0.0-alpha.1",
@@ -2147,6 +2178,30 @@ module.exports = {
 	"106.0.5249.103": [
 		"21.1.1"
 	],
+	"106.0.5249.119": [
+		"21.2.0"
+	],
+	"106.0.5249.165": [
+		"21.2.1"
+	],
+	"106.0.5249.168": [
+		"21.2.2",
+		"21.2.3"
+	],
+	"106.0.5249.181": [
+		"21.3.0",
+		"21.3.1"
+	],
+	"106.0.5249.199": [
+		"21.3.3",
+		"21.3.4",
+		"21.3.5",
+		"21.4.0",
+		"21.4.1",
+		"21.4.2",
+		"21.4.3",
+		"21.4.4"
+	],
 	"107.0.5286.0": [
 		"22.0.0-alpha.1",
 		"22.0.0-nightly.20220909",
@@ -2171,6 +2226,7 @@ module.exports = {
 		"22.0.0-alpha.3",
 		"22.0.0-alpha.4",
 		"22.0.0-alpha.5",
+		"22.0.0-alpha.6",
 		"23.0.0-nightly.20221004",
 		"23.0.0-nightly.20221005",
 		"23.0.0-nightly.20221006",
@@ -2182,7 +2238,762 @@ module.exports = {
 		"23.0.0-nightly.20221014",
 		"23.0.0-nightly.20221017"
 	],
+	"108.0.5355.0": [
+		"22.0.0-alpha.7",
+		"23.0.0-nightly.20221018",
+		"23.0.0-nightly.20221019",
+		"23.0.0-nightly.20221020",
+		"23.0.0-nightly.20221021",
+		"23.0.0-nightly.20221024",
+		"23.0.0-nightly.20221026"
+	],
+	"108.0.5359.10": [
+		"22.0.0-alpha.8",
+		"22.0.0-beta.1",
+		"22.0.0-beta.2",
+		"22.0.0-beta.3"
+	],
+	"108.0.5359.29": [
+		"22.0.0-beta.4"
+	],
+	"108.0.5359.40": [
+		"22.0.0-beta.5",
+		"22.0.0-beta.6"
+	],
+	"108.0.5359.48": [
+		"22.0.0-beta.7",
+		"22.0.0-beta.8"
+	],
 	"107.0.5274.0": [
 		"22.0.0-nightly.20220908"
+	],
+	"108.0.5359.62": [
+		"22.0.0"
+	],
+	"108.0.5359.125": [
+		"22.0.1"
+	],
+	"108.0.5359.179": [
+		"22.0.2",
+		"22.0.3",
+		"22.1.0"
+	],
+	"108.0.5359.215": [
+		"22.2.0",
+		"22.2.1",
+		"22.3.0",
+		"22.3.1",
+		"22.3.2",
+		"22.3.3",
+		"22.3.4",
+		"22.3.5",
+		"22.3.6",
+		"22.3.7",
+		"22.3.8",
+		"22.3.9",
+		"22.3.10",
+		"22.3.11",
+		"22.3.12",
+		"22.3.13",
+		"22.3.14",
+		"22.3.15",
+		"22.3.16",
+		"22.3.17",
+		"22.3.18",
+		"22.3.20",
+		"22.3.21",
+		"22.3.22",
+		"22.3.23",
+		"22.3.24",
+		"22.3.25",
+		"22.3.26",
+		"22.3.27"
+	],
+	"110.0.5415.0": [
+		"23.0.0-alpha.1",
+		"23.0.0-nightly.20221118",
+		"23.0.0-nightly.20221121",
+		"23.0.0-nightly.20221122",
+		"23.0.0-nightly.20221123",
+		"23.0.0-nightly.20221124",
+		"23.0.0-nightly.20221125",
+		"23.0.0-nightly.20221128",
+		"23.0.0-nightly.20221129",
+		"23.0.0-nightly.20221130",
+		"24.0.0-nightly.20221201",
+		"24.0.0-nightly.20221202",
+		"24.0.0-nightly.20221205"
+	],
+	"110.0.5451.0": [
+		"23.0.0-alpha.2",
+		"23.0.0-alpha.3",
+		"24.0.0-nightly.20221206",
+		"24.0.0-nightly.20221207",
+		"24.0.0-nightly.20221208",
+		"24.0.0-nightly.20221213",
+		"24.0.0-nightly.20221214",
+		"24.0.0-nightly.20221215",
+		"24.0.0-nightly.20221216"
+	],
+	"110.0.5478.5": [
+		"23.0.0-beta.1",
+		"23.0.0-beta.2",
+		"23.0.0-beta.3"
+	],
+	"110.0.5481.30": [
+		"23.0.0-beta.4"
+	],
+	"110.0.5481.38": [
+		"23.0.0-beta.5"
+	],
+	"110.0.5481.52": [
+		"23.0.0-beta.6",
+		"23.0.0-beta.8"
+	],
+	"109.0.5382.0": [
+		"23.0.0-nightly.20221027",
+		"23.0.0-nightly.20221028",
+		"23.0.0-nightly.20221031",
+		"23.0.0-nightly.20221101",
+		"23.0.0-nightly.20221102",
+		"23.0.0-nightly.20221103",
+		"23.0.0-nightly.20221104",
+		"23.0.0-nightly.20221107",
+		"23.0.0-nightly.20221108",
+		"23.0.0-nightly.20221109",
+		"23.0.0-nightly.20221110",
+		"23.0.0-nightly.20221111",
+		"23.0.0-nightly.20221114",
+		"23.0.0-nightly.20221115",
+		"23.0.0-nightly.20221116",
+		"23.0.0-nightly.20221117"
+	],
+	"110.0.5481.77": [
+		"23.0.0"
+	],
+	"110.0.5481.100": [
+		"23.1.0"
+	],
+	"110.0.5481.104": [
+		"23.1.1"
+	],
+	"110.0.5481.177": [
+		"23.1.2"
+	],
+	"110.0.5481.179": [
+		"23.1.3"
+	],
+	"110.0.5481.192": [
+		"23.1.4",
+		"23.2.0"
+	],
+	"110.0.5481.208": [
+		"23.2.1",
+		"23.2.2",
+		"23.2.3",
+		"23.2.4",
+		"23.3.0",
+		"23.3.1",
+		"23.3.2",
+		"23.3.3",
+		"23.3.4",
+		"23.3.5",
+		"23.3.6",
+		"23.3.7",
+		"23.3.8",
+		"23.3.9",
+		"23.3.10",
+		"23.3.11",
+		"23.3.12",
+		"23.3.13"
+	],
+	"111.0.5560.0": [
+		"24.0.0-alpha.1",
+		"24.0.0-alpha.2",
+		"24.0.0-alpha.3",
+		"24.0.0-alpha.4",
+		"24.0.0-alpha.5",
+		"24.0.0-alpha.6",
+		"24.0.0-alpha.7",
+		"24.0.0-nightly.20230203",
+		"24.0.0-nightly.20230206",
+		"24.0.0-nightly.20230207",
+		"24.0.0-nightly.20230208",
+		"24.0.0-nightly.20230209",
+		"25.0.0-nightly.20230210",
+		"25.0.0-nightly.20230214",
+		"25.0.0-nightly.20230215",
+		"25.0.0-nightly.20230216",
+		"25.0.0-nightly.20230217",
+		"25.0.0-nightly.20230220",
+		"25.0.0-nightly.20230221",
+		"25.0.0-nightly.20230222",
+		"25.0.0-nightly.20230223",
+		"25.0.0-nightly.20230224",
+		"25.0.0-nightly.20230227",
+		"25.0.0-nightly.20230228",
+		"25.0.0-nightly.20230301",
+		"25.0.0-nightly.20230302",
+		"25.0.0-nightly.20230303",
+		"25.0.0-nightly.20230306",
+		"25.0.0-nightly.20230307",
+		"25.0.0-nightly.20230308",
+		"25.0.0-nightly.20230309",
+		"25.0.0-nightly.20230310"
+	],
+	"111.0.5563.50": [
+		"24.0.0-beta.1",
+		"24.0.0-beta.2"
+	],
+	"112.0.5615.20": [
+		"24.0.0-beta.3",
+		"24.0.0-beta.4"
+	],
+	"112.0.5615.29": [
+		"24.0.0-beta.5"
+	],
+	"112.0.5615.39": [
+		"24.0.0-beta.6",
+		"24.0.0-beta.7"
+	],
+	"111.0.5518.0": [
+		"24.0.0-nightly.20230109",
+		"24.0.0-nightly.20230110",
+		"24.0.0-nightly.20230111",
+		"24.0.0-nightly.20230112",
+		"24.0.0-nightly.20230113",
+		"24.0.0-nightly.20230116",
+		"24.0.0-nightly.20230117",
+		"24.0.0-nightly.20230118",
+		"24.0.0-nightly.20230119",
+		"24.0.0-nightly.20230120",
+		"24.0.0-nightly.20230123",
+		"24.0.0-nightly.20230124",
+		"24.0.0-nightly.20230125",
+		"24.0.0-nightly.20230126",
+		"24.0.0-nightly.20230127",
+		"24.0.0-nightly.20230131",
+		"24.0.0-nightly.20230201",
+		"24.0.0-nightly.20230202"
+	],
+	"112.0.5615.49": [
+		"24.0.0"
+	],
+	"112.0.5615.50": [
+		"24.1.0",
+		"24.1.1"
+	],
+	"112.0.5615.87": [
+		"24.1.2"
+	],
+	"112.0.5615.165": [
+		"24.1.3",
+		"24.2.0",
+		"24.3.0"
+	],
+	"112.0.5615.183": [
+		"24.3.1"
+	],
+	"112.0.5615.204": [
+		"24.4.0",
+		"24.4.1",
+		"24.5.0",
+		"24.5.1",
+		"24.6.0",
+		"24.6.1",
+		"24.6.2",
+		"24.6.3",
+		"24.6.4",
+		"24.6.5",
+		"24.7.0",
+		"24.7.1",
+		"24.8.0",
+		"24.8.1",
+		"24.8.2",
+		"24.8.3",
+		"24.8.4",
+		"24.8.5",
+		"24.8.6",
+		"24.8.7",
+		"24.8.8"
+	],
+	"114.0.5694.0": [
+		"25.0.0-alpha.1",
+		"25.0.0-alpha.2",
+		"25.0.0-nightly.20230405",
+		"26.0.0-nightly.20230406",
+		"26.0.0-nightly.20230407",
+		"26.0.0-nightly.20230410",
+		"26.0.0-nightly.20230411"
+	],
+	"114.0.5710.0": [
+		"25.0.0-alpha.3",
+		"25.0.0-alpha.4",
+		"26.0.0-nightly.20230413",
+		"26.0.0-nightly.20230414",
+		"26.0.0-nightly.20230417"
+	],
+	"114.0.5719.0": [
+		"25.0.0-alpha.5",
+		"25.0.0-alpha.6",
+		"25.0.0-beta.1",
+		"25.0.0-beta.2",
+		"25.0.0-beta.3",
+		"26.0.0-nightly.20230421",
+		"26.0.0-nightly.20230424",
+		"26.0.0-nightly.20230425",
+		"26.0.0-nightly.20230426",
+		"26.0.0-nightly.20230427",
+		"26.0.0-nightly.20230428",
+		"26.0.0-nightly.20230501",
+		"26.0.0-nightly.20230502",
+		"26.0.0-nightly.20230503",
+		"26.0.0-nightly.20230504",
+		"26.0.0-nightly.20230505",
+		"26.0.0-nightly.20230508",
+		"26.0.0-nightly.20230509",
+		"26.0.0-nightly.20230510"
+	],
+	"114.0.5735.16": [
+		"25.0.0-beta.4",
+		"25.0.0-beta.5",
+		"25.0.0-beta.6",
+		"25.0.0-beta.7"
+	],
+	"114.0.5735.35": [
+		"25.0.0-beta.8"
+	],
+	"114.0.5735.45": [
+		"25.0.0-beta.9",
+		"25.0.0",
+		"25.0.1"
+	],
+	"113.0.5636.0": [
+		"25.0.0-nightly.20230314"
+	],
+	"113.0.5651.0": [
+		"25.0.0-nightly.20230315"
+	],
+	"113.0.5653.0": [
+		"25.0.0-nightly.20230317"
+	],
+	"113.0.5660.0": [
+		"25.0.0-nightly.20230320"
+	],
+	"113.0.5664.0": [
+		"25.0.0-nightly.20230321"
+	],
+	"113.0.5666.0": [
+		"25.0.0-nightly.20230322"
+	],
+	"113.0.5668.0": [
+		"25.0.0-nightly.20230323"
+	],
+	"113.0.5670.0": [
+		"25.0.0-nightly.20230324",
+		"25.0.0-nightly.20230327",
+		"25.0.0-nightly.20230328",
+		"25.0.0-nightly.20230329",
+		"25.0.0-nightly.20230330"
+	],
+	"114.0.5684.0": [
+		"25.0.0-nightly.20230331",
+		"25.0.0-nightly.20230403"
+	],
+	"114.0.5692.0": [
+		"25.0.0-nightly.20230404"
+	],
+	"114.0.5735.106": [
+		"25.1.0",
+		"25.1.1"
+	],
+	"114.0.5735.134": [
+		"25.2.0"
+	],
+	"114.0.5735.199": [
+		"25.3.0"
+	],
+	"114.0.5735.243": [
+		"25.3.1"
+	],
+	"114.0.5735.248": [
+		"25.3.2",
+		"25.4.0"
+	],
+	"114.0.5735.289": [
+		"25.5.0",
+		"25.6.0",
+		"25.7.0",
+		"25.8.0",
+		"25.8.1",
+		"25.8.2",
+		"25.8.3",
+		"25.8.4",
+		"25.9.0",
+		"25.9.1",
+		"25.9.2",
+		"25.9.3",
+		"25.9.4",
+		"25.9.5",
+		"25.9.6",
+		"25.9.7",
+		"25.9.8"
+	],
+	"116.0.5791.0": [
+		"26.0.0-alpha.1",
+		"26.0.0-alpha.2",
+		"26.0.0-alpha.3",
+		"26.0.0-alpha.4",
+		"26.0.0-alpha.5",
+		"26.0.0-nightly.20230526",
+		"26.0.0-nightly.20230529",
+		"26.0.0-nightly.20230530",
+		"26.0.0-nightly.20230531",
+		"27.0.0-nightly.20230601",
+		"27.0.0-nightly.20230602",
+		"27.0.0-nightly.20230605",
+		"27.0.0-nightly.20230606",
+		"27.0.0-nightly.20230607",
+		"27.0.0-nightly.20230609"
+	],
+	"116.0.5815.0": [
+		"26.0.0-alpha.6",
+		"27.0.0-nightly.20230612",
+		"27.0.0-nightly.20230613"
+	],
+	"116.0.5831.0": [
+		"26.0.0-alpha.7",
+		"27.0.0-nightly.20230615"
+	],
+	"116.0.5845.0": [
+		"26.0.0-alpha.8",
+		"26.0.0-beta.1",
+		"27.0.0-nightly.20230622",
+		"27.0.0-nightly.20230623",
+		"27.0.0-nightly.20230626",
+		"27.0.0-nightly.20230627",
+		"27.0.0-nightly.20230628",
+		"27.0.0-nightly.20230629",
+		"27.0.0-nightly.20230630"
+	],
+	"116.0.5845.14": [
+		"26.0.0-beta.2",
+		"26.0.0-beta.3",
+		"26.0.0-beta.4",
+		"26.0.0-beta.5",
+		"26.0.0-beta.6",
+		"26.0.0-beta.7"
+	],
+	"116.0.5845.42": [
+		"26.0.0-beta.8",
+		"26.0.0-beta.9"
+	],
+	"116.0.5845.49": [
+		"26.0.0-beta.10",
+		"26.0.0-beta.11"
+	],
+	"116.0.5845.62": [
+		"26.0.0-beta.12"
+	],
+	"114.0.5708.0": [
+		"26.0.0-nightly.20230412"
+	],
+	"114.0.5715.0": [
+		"26.0.0-nightly.20230418"
+	],
+	"115.0.5760.0": [
+		"26.0.0-nightly.20230511",
+		"26.0.0-nightly.20230512",
+		"26.0.0-nightly.20230515",
+		"26.0.0-nightly.20230516",
+		"26.0.0-nightly.20230517",
+		"26.0.0-nightly.20230518",
+		"26.0.0-nightly.20230519",
+		"26.0.0-nightly.20230522",
+		"26.0.0-nightly.20230523"
+	],
+	"115.0.5786.0": [
+		"26.0.0-nightly.20230524"
+	],
+	"115.0.5790.0": [
+		"26.0.0-nightly.20230525"
+	],
+	"116.0.5845.82": [
+		"26.0.0"
+	],
+	"116.0.5845.97": [
+		"26.1.0"
+	],
+	"116.0.5845.179": [
+		"26.2.0"
+	],
+	"116.0.5845.188": [
+		"26.2.1"
+	],
+	"116.0.5845.190": [
+		"26.2.2",
+		"26.2.3",
+		"26.2.4"
+	],
+	"116.0.5845.228": [
+		"26.3.0",
+		"26.4.0",
+		"26.4.1",
+		"26.4.2",
+		"26.4.3",
+		"26.5.0",
+		"26.6.0",
+		"26.6.1",
+		"26.6.2",
+		"26.6.3"
+	],
+	"118.0.5949.0": [
+		"27.0.0-alpha.1",
+		"27.0.0-alpha.2",
+		"27.0.0-alpha.3",
+		"27.0.0-alpha.4",
+		"27.0.0-alpha.5",
+		"27.0.0-alpha.6",
+		"27.0.0-nightly.20230816",
+		"28.0.0-nightly.20230817",
+		"28.0.0-nightly.20230818",
+		"28.0.0-nightly.20230821",
+		"28.0.0-nightly.20230822",
+		"28.0.0-nightly.20230823",
+		"28.0.0-nightly.20230824",
+		"28.0.0-nightly.20230825",
+		"28.0.0-nightly.20230828",
+		"28.0.0-nightly.20230829",
+		"28.0.0-nightly.20230830",
+		"28.0.0-nightly.20230831"
+	],
+	"118.0.5993.5": [
+		"27.0.0-beta.1",
+		"27.0.0-beta.2",
+		"27.0.0-beta.3"
+	],
+	"118.0.5993.11": [
+		"27.0.0-beta.4"
+	],
+	"118.0.5993.18": [
+		"27.0.0-beta.5",
+		"27.0.0-beta.6",
+		"27.0.0-beta.7",
+		"27.0.0-beta.8",
+		"27.0.0-beta.9"
+	],
+	"116.0.5829.0": [
+		"27.0.0-nightly.20230614"
+	],
+	"116.0.5833.0": [
+		"27.0.0-nightly.20230616",
+		"27.0.0-nightly.20230619",
+		"27.0.0-nightly.20230620",
+		"27.0.0-nightly.20230621"
+	],
+	"117.0.5852.0": [
+		"27.0.0-nightly.20230703",
+		"27.0.0-nightly.20230704",
+		"27.0.0-nightly.20230705",
+		"27.0.0-nightly.20230706",
+		"27.0.0-nightly.20230707",
+		"27.0.0-nightly.20230710",
+		"27.0.0-nightly.20230711",
+		"27.0.0-nightly.20230712",
+		"27.0.0-nightly.20230713",
+		"27.0.0-nightly.20230714"
+	],
+	"117.0.5884.1": [
+		"27.0.0-nightly.20230717",
+		"27.0.0-nightly.20230718"
+	],
+	"117.0.5892.0": [
+		"27.0.0-nightly.20230719"
+	],
+	"117.0.5897.0": [
+		"27.0.0-nightly.20230720",
+		"27.0.0-nightly.20230721",
+		"27.0.0-nightly.20230724",
+		"27.0.0-nightly.20230725",
+		"27.0.0-nightly.20230726",
+		"27.0.0-nightly.20230727",
+		"27.0.0-nightly.20230728",
+		"27.0.0-nightly.20230731"
+	],
+	"117.0.5911.0": [
+		"27.0.0-nightly.20230801",
+		"27.0.0-nightly.20230802",
+		"27.0.0-nightly.20230803"
+	],
+	"117.0.5921.0": [
+		"27.0.0-nightly.20230804",
+		"27.0.0-nightly.20230807",
+		"27.0.0-nightly.20230808",
+		"27.0.0-nightly.20230814",
+		"27.0.0-nightly.20230815"
+	],
+	"118.0.5993.54": [
+		"27.0.0"
+	],
+	"118.0.5993.89": [
+		"27.0.1",
+		"27.0.2"
+	],
+	"118.0.5993.120": [
+		"27.0.3"
+	],
+	"118.0.5993.129": [
+		"27.0.4"
+	],
+	"118.0.5993.144": [
+		"27.1.0",
+		"27.1.2"
+	],
+	"118.0.5993.159": [
+		"27.1.3",
+		"27.2.0"
+	],
+	"119.0.6045.0": [
+		"28.0.0-alpha.1",
+		"28.0.0-alpha.2",
+		"28.0.0-nightly.20231006",
+		"28.0.0-nightly.20231009",
+		"28.0.0-nightly.20231010",
+		"28.0.0-nightly.20231011",
+		"29.0.0-nightly.20231012",
+		"29.0.0-nightly.20231013",
+		"29.0.0-nightly.20231016",
+		"29.0.0-nightly.20231017",
+		"29.0.0-nightly.20231018",
+		"29.0.0-nightly.20231019",
+		"29.0.0-nightly.20231020",
+		"29.0.0-nightly.20231023",
+		"29.0.0-nightly.20231024"
+	],
+	"119.0.6045.21": [
+		"28.0.0-alpha.3",
+		"28.0.0-alpha.4"
+	],
+	"119.0.6045.33": [
+		"28.0.0-alpha.5",
+		"28.0.0-alpha.6",
+		"28.0.0-alpha.7",
+		"28.0.0-beta.1"
+	],
+	"120.0.6099.0": [
+		"28.0.0-beta.2"
+	],
+	"120.0.6099.5": [
+		"28.0.0-beta.3",
+		"28.0.0-beta.4"
+	],
+	"120.0.6099.18": [
+		"28.0.0-beta.5",
+		"28.0.0-beta.6",
+		"28.0.0-beta.7",
+		"28.0.0-beta.8",
+		"28.0.0-beta.9",
+		"28.0.0-beta.10"
+	],
+	"120.0.6099.35": [
+		"28.0.0-beta.11"
+	],
+	"118.0.5991.0": [
+		"28.0.0-nightly.20230906"
+	],
+	"118.0.5993.0": [
+		"28.0.0-nightly.20230907",
+		"28.0.0-nightly.20230908",
+		"28.0.0-nightly.20230911",
+		"28.0.0-nightly.20230912",
+		"28.0.0-nightly.20230913",
+		"28.0.0-nightly.20230914",
+		"28.0.0-nightly.20230915"
+	],
+	"119.0.6006.0": [
+		"28.0.0-nightly.20230919"
+	],
+	"119.0.6017.0": [
+		"28.0.0-nightly.20230920"
+	],
+	"119.0.6019.2": [
+		"28.0.0-nightly.20230921",
+		"28.0.0-nightly.20230925",
+		"28.0.0-nightly.20230926",
+		"28.0.0-nightly.20230927",
+		"28.0.0-nightly.20230928"
+	],
+	"119.0.6029.0": [
+		"28.0.0-nightly.20230929",
+		"28.0.0-nightly.20231002"
+	],
+	"119.0.6043.0": [
+		"28.0.0-nightly.20231003",
+		"28.0.0-nightly.20231004",
+		"28.0.0-nightly.20231005"
+	],
+	"120.0.6099.56": [
+		"28.0.0"
+	],
+	"120.0.6099.109": [
+		"28.1.0"
+	],
+	"121.0.6147.0": [
+		"29.0.0-alpha.1",
+		"29.0.0-alpha.2",
+		"29.0.0-alpha.3",
+		"29.0.0-nightly.20231129",
+		"29.0.0-nightly.20231130",
+		"29.0.0-nightly.20231201",
+		"29.0.0-nightly.20231204",
+		"29.0.0-nightly.20231205",
+		"29.0.0-nightly.20231206",
+		"30.0.0-nightly.20231207",
+		"30.0.0-nightly.20231208",
+		"30.0.0-nightly.20231211"
+	],
+	"121.0.6159.0": [
+		"29.0.0-alpha.4",
+		"29.0.0-alpha.5",
+		"30.0.0-nightly.20231212",
+		"30.0.0-nightly.20231213",
+		"30.0.0-nightly.20231214",
+		"30.0.0-nightly.20231215",
+		"30.0.0-nightly.20231218"
+	],
+	"120.0.6078.0": [
+		"29.0.0-nightly.20231025",
+		"29.0.0-nightly.20231026",
+		"29.0.0-nightly.20231027",
+		"29.0.0-nightly.20231030",
+		"29.0.0-nightly.20231031",
+		"29.0.0-nightly.20231101"
+	],
+	"121.0.6100.0": [
+		"29.0.0-nightly.20231102",
+		"29.0.0-nightly.20231103"
+	],
+	"121.0.6104.0": [
+		"29.0.0-nightly.20231106"
+	],
+	"121.0.6110.0": [
+		"29.0.0-nightly.20231107",
+		"29.0.0-nightly.20231108",
+		"29.0.0-nightly.20231109",
+		"29.0.0-nightly.20231110",
+		"29.0.0-nightly.20231113",
+		"29.0.0-nightly.20231114"
+	],
+	"121.0.6116.0": [
+		"29.0.0-nightly.20231115",
+		"29.0.0-nightly.20231116",
+		"29.0.0-nightly.20231117",
+		"29.0.0-nightly.20231120",
+		"29.0.0-nightly.20231121",
+		"29.0.0-nightly.20231122",
+		"29.0.0-nightly.20231123",
+		"29.0.0-nightly.20231124",
+		"29.0.0-nightly.20231127",
+		"29.0.0-nightly.20231128"
 	]
 };
\ No newline at end of file
