@@ -343,6 +343,7 @@ module.exports = {
 	"6.0.0-beta.13": "76.0.3809.60",
 	"6.0.0-beta.14": "76.0.3809.68",
 	"6.0.0-beta.15": "76.0.3809.74",
+	"6.0.0-nightly.20190123": "72.0.3626.52",
 	"6.0.0-nightly.20190212": "72.0.3626.107",
 	"6.0.0-nightly.20190213": "72.0.3626.110",
 	"6.0.0-nightly.20190311": "74.0.3724.8",
@@ -481,15 +482,18 @@ module.exports = {
 	"8.0.0-nightly.20190909": "78.0.3892.0",
 	"8.0.0-nightly.20190910": "78.0.3892.0",
 	"8.0.0-nightly.20190911": "78.0.3892.0",
+	"8.0.0-nightly.20190912": "78.0.3892.0",
 	"8.0.0-nightly.20190913": "78.0.3892.0",
 	"8.0.0-nightly.20190914": "78.0.3892.0",
 	"8.0.0-nightly.20190915": "78.0.3892.0",
 	"8.0.0-nightly.20190917": "78.0.3892.0",
 	"8.0.0-nightly.20190919": "79.0.3915.0",
 	"8.0.0-nightly.20190920": "79.0.3915.0",
+	"8.0.0-nightly.20190922": "79.0.3919.0",
 	"8.0.0-nightly.20190923": "79.0.3919.0",
 	"8.0.0-nightly.20190924": "79.0.3919.0",
 	"8.0.0-nightly.20190926": "79.0.3919.0",
+	"8.0.0-nightly.20190928": "79.0.3919.0",
 	"8.0.0-nightly.20190929": "79.0.3919.0",
 	"8.0.0-nightly.20190930": "79.0.3919.0",
 	"8.0.0-nightly.20191001": "79.0.3919.0",
@@ -505,6 +509,7 @@ module.exports = {
 	"8.0.0-nightly.20191021": "79.0.3931.0",
 	"8.0.0-nightly.20191023": "79.0.3931.0",
 	"8.0.0-nightly.20191101": "80.0.3952.0",
+	"8.0.0-nightly.20191103": "80.0.3952.0",
 	"8.0.0-nightly.20191105": "80.0.3952.0",
 	"8.0.0": "80.0.3987.86",
 	"8.0.1": "80.0.3987.86",
@@ -540,6 +545,7 @@ module.exports = {
 	"9.0.0-beta.7": "82.0.4058.2",
 	"9.0.0-beta.9": "82.0.4058.2",
 	"9.0.0-beta.10": "82.0.4085.10",
+	"9.0.0-beta.11": "82.0.4085.14",
 	"9.0.0-beta.12": "82.0.4085.14",
 	"9.0.0-beta.13": "82.0.4085.14",
 	"9.0.0-beta.14": "82.0.4085.27",
@@ -557,12 +563,15 @@ module.exports = {
 	"9.0.0-nightly.20191122": "80.0.3954.0",
 	"9.0.0-nightly.20191123": "80.0.3954.0",
 	"9.0.0-nightly.20191124": "80.0.3954.0",
+	"9.0.0-nightly.20191126": "80.0.3954.0",
+	"9.0.0-nightly.20191128": "80.0.3954.0",
 	"9.0.0-nightly.20191129": "80.0.3954.0",
 	"9.0.0-nightly.20191130": "80.0.3954.0",
 	"9.0.0-nightly.20191201": "80.0.3954.0",
 	"9.0.0-nightly.20191202": "80.0.3954.0",
 	"9.0.0-nightly.20191203": "80.0.3954.0",
 	"9.0.0-nightly.20191204": "80.0.3954.0",
+	"9.0.0-nightly.20191205": "80.0.3954.0",
 	"9.0.0-nightly.20191210": "80.0.3954.0",
 	"9.0.0-nightly.20191220": "81.0.3994.0",
 	"9.0.0-nightly.20191221": "81.0.3994.0",
@@ -832,6 +841,10 @@ module.exports = {
 	"12.0.0-nightly.20200910": "86.0.4234.0",
 	"12.0.0-nightly.20200911": "86.0.4234.0",
 	"12.0.0-nightly.20200914": "86.0.4234.0",
+	"12.0.0-nightly.20201002": "87.0.4268.0",
+	"12.0.0-nightly.20201007": "87.0.4268.0",
+	"12.0.0-nightly.20201009": "87.0.4268.0",
+	"12.0.0-nightly.20201012": "87.0.4268.0",
 	"12.0.0-nightly.20201013": "87.0.4268.0",
 	"12.0.0-nightly.20201014": "87.0.4268.0",
 	"12.0.0-nightly.20201015": "87.0.4268.0",
@@ -880,6 +893,7 @@ module.exports = {
 	"13.0.0-beta.7": "90.0.4415.0",
 	"13.0.0-beta.8": "90.0.4415.0",
 	"13.0.0-beta.9": "90.0.4415.0",
+	"13.0.0-beta.10": "90.0.4415.0",
 	"13.0.0-beta.11": "90.0.4415.0",
 	"13.0.0-beta.12": "90.0.4415.0",
 	"13.0.0-beta.13": "90.0.4415.0",
@@ -892,6 +906,7 @@ module.exports = {
 	"13.0.0-beta.22": "91.0.4472.33",
 	"13.0.0-beta.23": "91.0.4472.33",
 	"13.0.0-beta.24": "91.0.4472.38",
+	"13.0.0-beta.25": "91.0.4472.38",
 	"13.0.0-beta.26": "91.0.4472.38",
 	"13.0.0-beta.27": "91.0.4472.38",
 	"13.0.0-beta.28": "91.0.4472.38",
@@ -1377,6 +1392,11 @@ module.exports = {
 	"18.3.7": "100.0.4896.160",
 	"18.3.8": "100.0.4896.160",
 	"18.3.9": "100.0.4896.160",
+	"18.3.11": "100.0.4896.160",
+	"18.3.12": "100.0.4896.160",
+	"18.3.13": "100.0.4896.160",
+	"18.3.14": "100.0.4896.160",
+	"18.3.15": "100.0.4896.160",
 	"19.0.0-alpha.1": "102.0.4962.3",
 	"19.0.0-alpha.2": "102.0.4971.0",
 	"19.0.0-alpha.3": "102.0.4971.0",
@@ -1427,6 +1447,19 @@ module.exports = {
 	"19.0.12": "102.0.5005.167",
 	"19.0.13": "102.0.5005.167",
 	"19.0.14": "102.0.5005.167",
+	"19.0.15": "102.0.5005.167",
+	"19.0.16": "102.0.5005.167",
+	"19.0.17": "102.0.5005.167",
+	"19.1.0": "102.0.5005.167",
+	"19.1.1": "102.0.5005.167",
+	"19.1.2": "102.0.5005.167",
+	"19.1.3": "102.0.5005.167",
+	"19.1.4": "102.0.5005.167",
+	"19.1.5": "102.0.5005.167",
+	"19.1.6": "102.0.5005.167",
+	"19.1.7": "102.0.5005.167",
+	"19.1.8": "102.0.5005.167",
+	"19.1.9": "102.0.5005.167",
 	"20.0.0-alpha.1": "103.0.5044.0",
 	"20.0.0-alpha.2": "104.0.5073.0",
 	"20.0.0-alpha.3": "104.0.5073.0",
@@ -1481,11 +1514,38 @@ module.exports = {
 	"20.0.2": "104.0.5112.81",
 	"20.0.3": "104.0.5112.81",
 	"20.1.0": "104.0.5112.102",
+	"20.1.1": "104.0.5112.102",
+	"20.1.2": "104.0.5112.114",
+	"20.1.3": "104.0.5112.114",
+	"20.1.4": "104.0.5112.114",
+	"20.2.0": "104.0.5112.124",
+	"20.3.0": "104.0.5112.124",
+	"20.3.1": "104.0.5112.124",
+	"20.3.2": "104.0.5112.124",
+	"20.3.3": "104.0.5112.124",
+	"20.3.4": "104.0.5112.124",
+	"20.3.5": "104.0.5112.124",
+	"20.3.6": "104.0.5112.124",
+	"20.3.7": "104.0.5112.124",
+	"20.3.8": "104.0.5112.124",
+	"20.3.9": "104.0.5112.124",
+	"20.3.10": "104.0.5112.124",
+	"20.3.11": "104.0.5112.124",
+	"20.3.12": "104.0.5112.124",
 	"21.0.0-alpha.1": "105.0.5187.0",
 	"21.0.0-alpha.2": "105.0.5187.0",
 	"21.0.0-alpha.3": "105.0.5187.0",
 	"21.0.0-alpha.4": "105.0.5187.0",
 	"21.0.0-alpha.5": "105.0.5187.0",
+	"21.0.0-alpha.6": "106.0.5216.0",
+	"21.0.0-beta.1": "106.0.5216.0",
+	"21.0.0-beta.2": "106.0.5216.0",
+	"21.0.0-beta.3": "106.0.5216.0",
+	"21.0.0-beta.4": "106.0.5216.0",
+	"21.0.0-beta.5": "106.0.5216.0",
+	"21.0.0-beta.6": "106.0.5249.40",
+	"21.0.0-beta.7": "106.0.5249.40",
+	"21.0.0-beta.8": "106.0.5249.40",
 	"21.0.0-nightly.20220526": "103.0.5044.0",
 	"21.0.0-nightly.20220527": "103.0.5044.0",
 	"21.0.0-nightly.20220530": "103.0.5044.0",
@@ -1532,6 +1592,39 @@ module.exports = {
 	"21.0.0-nightly.20220728": "105.0.5187.0",
 	"21.0.0-nightly.20220801": "105.0.5187.0",
 	"21.0.0-nightly.20220802": "105.0.5187.0",
+	"21.0.0": "106.0.5249.51",
+	"21.0.1": "106.0.5249.61",
+	"21.1.0": "106.0.5249.91",
+	"21.1.1": "106.0.5249.103",
+	"21.2.0": "106.0.5249.119",
+	"21.2.1": "106.0.5249.165",
+	"21.2.2": "106.0.5249.168",
+	"21.2.3": "106.0.5249.168",
+	"21.3.0": "106.0.5249.181",
+	"21.3.1": "106.0.5249.181",
+	"21.3.3": "106.0.5249.199",
+	"21.3.4": "106.0.5249.199",
+	"21.3.5": "106.0.5249.199",
+	"21.4.0": "106.0.5249.199",
+	"21.4.1": "106.0.5249.199",
+	"21.4.2": "106.0.5249.199",
+	"21.4.3": "106.0.5249.199",
+	"21.4.4": "106.0.5249.199",
+	"22.0.0-alpha.1": "107.0.5286.0",
+	"22.0.0-alpha.3": "108.0.5329.0",
+	"22.0.0-alpha.4": "108.0.5329.0",
+	"22.0.0-alpha.5": "108.0.5329.0",
+	"22.0.0-alpha.6": "108.0.5329.0",
+	"22.0.0-alpha.7": "108.0.5355.0",
+	"22.0.0-alpha.8": "108.0.5359.10",
+	"22.0.0-beta.1": "108.0.5359.10",
+	"22.0.0-beta.2": "108.0.5359.10",
+	"22.0.0-beta.3": "108.0.5359.10",
+	"22.0.0-beta.4": "108.0.5359.29",
+	"22.0.0-beta.5": "108.0.5359.40",
+	"22.0.0-beta.6": "108.0.5359.40",
+	"22.0.0-beta.7": "108.0.5359.48",
+	"22.0.0-beta.8": "108.0.5359.48",
 	"22.0.0-nightly.20220808": "105.0.5187.0",
 	"22.0.0-nightly.20220809": "105.0.5187.0",
 	"22.0.0-nightly.20220810": "105.0.5187.0",
@@ -1542,5 +1635,551 @@ module.exports = {
 	"22.0.0-nightly.20220817": "105.0.5187.0",
 	"22.0.0-nightly.20220822": "106.0.5216.0",
 	"22.0.0-nightly.20220823": "106.0.5216.0",
-	"22.0.0-nightly.20220824": "106.0.5216.0"
+	"22.0.0-nightly.20220824": "106.0.5216.0",
+	"22.0.0-nightly.20220825": "106.0.5216.0",
+	"22.0.0-nightly.20220829": "106.0.5216.0",
+	"22.0.0-nightly.20220830": "106.0.5216.0",
+	"22.0.0-nightly.20220831": "106.0.5216.0",
+	"22.0.0-nightly.20220901": "106.0.5216.0",
+	"22.0.0-nightly.20220902": "106.0.5216.0",
+	"22.0.0-nightly.20220905": "106.0.5216.0",
+	"22.0.0-nightly.20220908": "107.0.5274.0",
+	"22.0.0-nightly.20220909": "107.0.5286.0",
+	"22.0.0-nightly.20220912": "107.0.5286.0",
+	"22.0.0-nightly.20220913": "107.0.5286.0",
+	"22.0.0-nightly.20220914": "107.0.5286.0",
+	"22.0.0-nightly.20220915": "107.0.5286.0",
+	"22.0.0-nightly.20220916": "107.0.5286.0",
+	"22.0.0-nightly.20220919": "107.0.5286.0",
+	"22.0.0-nightly.20220920": "107.0.5286.0",
+	"22.0.0-nightly.20220921": "107.0.5286.0",
+	"22.0.0-nightly.20220922": "107.0.5286.0",
+	"22.0.0-nightly.20220923": "107.0.5286.0",
+	"22.0.0-nightly.20220926": "107.0.5286.0",
+	"22.0.0-nightly.20220927": "107.0.5286.0",
+	"22.0.0-nightly.20220928": "107.0.5286.0",
+	"22.0.0": "108.0.5359.62",
+	"22.0.1": "108.0.5359.125",
+	"22.0.2": "108.0.5359.179",
+	"22.0.3": "108.0.5359.179",
+	"22.1.0": "108.0.5359.179",
+	"22.2.0": "108.0.5359.215",
+	"22.2.1": "108.0.5359.215",
+	"22.3.0": "108.0.5359.215",
+	"22.3.1": "108.0.5359.215",
+	"22.3.2": "108.0.5359.215",
+	"22.3.3": "108.0.5359.215",
+	"22.3.4": "108.0.5359.215",
+	"22.3.5": "108.0.5359.215",
+	"22.3.6": "108.0.5359.215",
+	"22.3.7": "108.0.5359.215",
+	"22.3.8": "108.0.5359.215",
+	"22.3.9": "108.0.5359.215",
+	"22.3.10": "108.0.5359.215",
+	"22.3.11": "108.0.5359.215",
+	"22.3.12": "108.0.5359.215",
+	"22.3.13": "108.0.5359.215",
+	"22.3.14": "108.0.5359.215",
+	"22.3.15": "108.0.5359.215",
+	"22.3.16": "108.0.5359.215",
+	"22.3.17": "108.0.5359.215",
+	"22.3.18": "108.0.5359.215",
+	"22.3.20": "108.0.5359.215",
+	"22.3.21": "108.0.5359.215",
+	"22.3.22": "108.0.5359.215",
+	"22.3.23": "108.0.5359.215",
+	"22.3.24": "108.0.5359.215",
+	"22.3.25": "108.0.5359.215",
+	"22.3.26": "108.0.5359.215",
+	"22.3.27": "108.0.5359.215",
+	"23.0.0-alpha.1": "110.0.5415.0",
+	"23.0.0-alpha.2": "110.0.5451.0",
+	"23.0.0-alpha.3": "110.0.5451.0",
+	"23.0.0-beta.1": "110.0.5478.5",
+	"23.0.0-beta.2": "110.0.5478.5",
+	"23.0.0-beta.3": "110.0.5478.5",
+	"23.0.0-beta.4": "110.0.5481.30",
+	"23.0.0-beta.5": "110.0.5481.38",
+	"23.0.0-beta.6": "110.0.5481.52",
+	"23.0.0-beta.8": "110.0.5481.52",
+	"23.0.0-nightly.20220929": "107.0.5286.0",
+	"23.0.0-nightly.20220930": "107.0.5286.0",
+	"23.0.0-nightly.20221003": "107.0.5286.0",
+	"23.0.0-nightly.20221004": "108.0.5329.0",
+	"23.0.0-nightly.20221005": "108.0.5329.0",
+	"23.0.0-nightly.20221006": "108.0.5329.0",
+	"23.0.0-nightly.20221007": "108.0.5329.0",
+	"23.0.0-nightly.20221010": "108.0.5329.0",
+	"23.0.0-nightly.20221011": "108.0.5329.0",
+	"23.0.0-nightly.20221012": "108.0.5329.0",
+	"23.0.0-nightly.20221013": "108.0.5329.0",
+	"23.0.0-nightly.20221014": "108.0.5329.0",
+	"23.0.0-nightly.20221017": "108.0.5329.0",
+	"23.0.0-nightly.20221018": "108.0.5355.0",
+	"23.0.0-nightly.20221019": "108.0.5355.0",
+	"23.0.0-nightly.20221020": "108.0.5355.0",
+	"23.0.0-nightly.20221021": "108.0.5355.0",
+	"23.0.0-nightly.20221024": "108.0.5355.0",
+	"23.0.0-nightly.20221026": "108.0.5355.0",
+	"23.0.0-nightly.20221027": "109.0.5382.0",
+	"23.0.0-nightly.20221028": "109.0.5382.0",
+	"23.0.0-nightly.20221031": "109.0.5382.0",
+	"23.0.0-nightly.20221101": "109.0.5382.0",
+	"23.0.0-nightly.20221102": "109.0.5382.0",
+	"23.0.0-nightly.20221103": "109.0.5382.0",
+	"23.0.0-nightly.20221104": "109.0.5382.0",
+	"23.0.0-nightly.20221107": "109.0.5382.0",
+	"23.0.0-nightly.20221108": "109.0.5382.0",
+	"23.0.0-nightly.20221109": "109.0.5382.0",
+	"23.0.0-nightly.20221110": "109.0.5382.0",
+	"23.0.0-nightly.20221111": "109.0.5382.0",
+	"23.0.0-nightly.20221114": "109.0.5382.0",
+	"23.0.0-nightly.20221115": "109.0.5382.0",
+	"23.0.0-nightly.20221116": "109.0.5382.0",
+	"23.0.0-nightly.20221117": "109.0.5382.0",
+	"23.0.0-nightly.20221118": "110.0.5415.0",
+	"23.0.0-nightly.20221121": "110.0.5415.0",
+	"23.0.0-nightly.20221122": "110.0.5415.0",
+	"23.0.0-nightly.20221123": "110.0.5415.0",
+	"23.0.0-nightly.20221124": "110.0.5415.0",
+	"23.0.0-nightly.20221125": "110.0.5415.0",
+	"23.0.0-nightly.20221128": "110.0.5415.0",
+	"23.0.0-nightly.20221129": "110.0.5415.0",
+	"23.0.0-nightly.20221130": "110.0.5415.0",
+	"23.0.0": "110.0.5481.77",
+	"23.1.0": "110.0.5481.100",
+	"23.1.1": "110.0.5481.104",
+	"23.1.2": "110.0.5481.177",
+	"23.1.3": "110.0.5481.179",
+	"23.1.4": "110.0.5481.192",
+	"23.2.0": "110.0.5481.192",
+	"23.2.1": "110.0.5481.208",
+	"23.2.2": "110.0.5481.208",
+	"23.2.3": "110.0.5481.208",
+	"23.2.4": "110.0.5481.208",
+	"23.3.0": "110.0.5481.208",
+	"23.3.1": "110.0.5481.208",
+	"23.3.2": "110.0.5481.208",
+	"23.3.3": "110.0.5481.208",
+	"23.3.4": "110.0.5481.208",
+	"23.3.5": "110.0.5481.208",
+	"23.3.6": "110.0.5481.208",
+	"23.3.7": "110.0.5481.208",
+	"23.3.8": "110.0.5481.208",
+	"23.3.9": "110.0.5481.208",
+	"23.3.10": "110.0.5481.208",
+	"23.3.11": "110.0.5481.208",
+	"23.3.12": "110.0.5481.208",
+	"23.3.13": "110.0.5481.208",
+	"24.0.0-alpha.1": "111.0.5560.0",
+	"24.0.0-alpha.2": "111.0.5560.0",
+	"24.0.0-alpha.3": "111.0.5560.0",
+	"24.0.0-alpha.4": "111.0.5560.0",
+	"24.0.0-alpha.5": "111.0.5560.0",
+	"24.0.0-alpha.6": "111.0.5560.0",
+	"24.0.0-alpha.7": "111.0.5560.0",
+	"24.0.0-beta.1": "111.0.5563.50",
+	"24.0.0-beta.2": "111.0.5563.50",
+	"24.0.0-beta.3": "112.0.5615.20",
+	"24.0.0-beta.4": "112.0.5615.20",
+	"24.0.0-beta.5": "112.0.5615.29",
+	"24.0.0-beta.6": "112.0.5615.39",
+	"24.0.0-beta.7": "112.0.5615.39",
+	"24.0.0-nightly.20221201": "110.0.5415.0",
+	"24.0.0-nightly.20221202": "110.0.5415.0",
+	"24.0.0-nightly.20221205": "110.0.5415.0",
+	"24.0.0-nightly.20221206": "110.0.5451.0",
+	"24.0.0-nightly.20221207": "110.0.5451.0",
+	"24.0.0-nightly.20221208": "110.0.5451.0",
+	"24.0.0-nightly.20221213": "110.0.5451.0",
+	"24.0.0-nightly.20221214": "110.0.5451.0",
+	"24.0.0-nightly.20221215": "110.0.5451.0",
+	"24.0.0-nightly.20221216": "110.0.5451.0",
+	"24.0.0-nightly.20230109": "111.0.5518.0",
+	"24.0.0-nightly.20230110": "111.0.5518.0",
+	"24.0.0-nightly.20230111": "111.0.5518.0",
+	"24.0.0-nightly.20230112": "111.0.5518.0",
+	"24.0.0-nightly.20230113": "111.0.5518.0",
+	"24.0.0-nightly.20230116": "111.0.5518.0",
+	"24.0.0-nightly.20230117": "111.0.5518.0",
+	"24.0.0-nightly.20230118": "111.0.5518.0",
+	"24.0.0-nightly.20230119": "111.0.5518.0",
+	"24.0.0-nightly.20230120": "111.0.5518.0",
+	"24.0.0-nightly.20230123": "111.0.5518.0",
+	"24.0.0-nightly.20230124": "111.0.5518.0",
+	"24.0.0-nightly.20230125": "111.0.5518.0",
+	"24.0.0-nightly.20230126": "111.0.5518.0",
+	"24.0.0-nightly.20230127": "111.0.5518.0",
+	"24.0.0-nightly.20230131": "111.0.5518.0",
+	"24.0.0-nightly.20230201": "111.0.5518.0",
+	"24.0.0-nightly.20230202": "111.0.5518.0",
+	"24.0.0-nightly.20230203": "111.0.5560.0",
+	"24.0.0-nightly.20230206": "111.0.5560.0",
+	"24.0.0-nightly.20230207": "111.0.5560.0",
+	"24.0.0-nightly.20230208": "111.0.5560.0",
+	"24.0.0-nightly.20230209": "111.0.5560.0",
+	"24.0.0": "112.0.5615.49",
+	"24.1.0": "112.0.5615.50",
+	"24.1.1": "112.0.5615.50",
+	"24.1.2": "112.0.5615.87",
+	"24.1.3": "112.0.5615.165",
+	"24.2.0": "112.0.5615.165",
+	"24.3.0": "112.0.5615.165",
+	"24.3.1": "112.0.5615.183",
+	"24.4.0": "112.0.5615.204",
+	"24.4.1": "112.0.5615.204",
+	"24.5.0": "112.0.5615.204",
+	"24.5.1": "112.0.5615.204",
+	"24.6.0": "112.0.5615.204",
+	"24.6.1": "112.0.5615.204",
+	"24.6.2": "112.0.5615.204",
+	"24.6.3": "112.0.5615.204",
+	"24.6.4": "112.0.5615.204",
+	"24.6.5": "112.0.5615.204",
+	"24.7.0": "112.0.5615.204",
+	"24.7.1": "112.0.5615.204",
+	"24.8.0": "112.0.5615.204",
+	"24.8.1": "112.0.5615.204",
+	"24.8.2": "112.0.5615.204",
+	"24.8.3": "112.0.5615.204",
+	"24.8.4": "112.0.5615.204",
+	"24.8.5": "112.0.5615.204",
+	"24.8.6": "112.0.5615.204",
+	"24.8.7": "112.0.5615.204",
+	"24.8.8": "112.0.5615.204",
+	"25.0.0-alpha.1": "114.0.5694.0",
+	"25.0.0-alpha.2": "114.0.5694.0",
+	"25.0.0-alpha.3": "114.0.5710.0",
+	"25.0.0-alpha.4": "114.0.5710.0",
+	"25.0.0-alpha.5": "114.0.5719.0",
+	"25.0.0-alpha.6": "114.0.5719.0",
+	"25.0.0-beta.1": "114.0.5719.0",
+	"25.0.0-beta.2": "114.0.5719.0",
+	"25.0.0-beta.3": "114.0.5719.0",
+	"25.0.0-beta.4": "114.0.5735.16",
+	"25.0.0-beta.5": "114.0.5735.16",
+	"25.0.0-beta.6": "114.0.5735.16",
+	"25.0.0-beta.7": "114.0.5735.16",
+	"25.0.0-beta.8": "114.0.5735.35",
+	"25.0.0-beta.9": "114.0.5735.45",
+	"25.0.0-nightly.20230210": "111.0.5560.0",
+	"25.0.0-nightly.20230214": "111.0.5560.0",
+	"25.0.0-nightly.20230215": "111.0.5560.0",
+	"25.0.0-nightly.20230216": "111.0.5560.0",
+	"25.0.0-nightly.20230217": "111.0.5560.0",
+	"25.0.0-nightly.20230220": "111.0.5560.0",
+	"25.0.0-nightly.20230221": "111.0.5560.0",
+	"25.0.0-nightly.20230222": "111.0.5560.0",
+	"25.0.0-nightly.20230223": "111.0.5560.0",
+	"25.0.0-nightly.20230224": "111.0.5560.0",
+	"25.0.0-nightly.20230227": "111.0.5560.0",
+	"25.0.0-nightly.20230228": "111.0.5560.0",
+	"25.0.0-nightly.20230301": "111.0.5560.0",
+	"25.0.0-nightly.20230302": "111.0.5560.0",
+	"25.0.0-nightly.20230303": "111.0.5560.0",
+	"25.0.0-nightly.20230306": "111.0.5560.0",
+	"25.0.0-nightly.20230307": "111.0.5560.0",
+	"25.0.0-nightly.20230308": "111.0.5560.0",
+	"25.0.0-nightly.20230309": "111.0.5560.0",
+	"25.0.0-nightly.20230310": "111.0.5560.0",
+	"25.0.0-nightly.20230314": "113.0.5636.0",
+	"25.0.0-nightly.20230315": "113.0.5651.0",
+	"25.0.0-nightly.20230317": "113.0.5653.0",
+	"25.0.0-nightly.20230320": "113.0.5660.0",
+	"25.0.0-nightly.20230321": "113.0.5664.0",
+	"25.0.0-nightly.20230322": "113.0.5666.0",
+	"25.0.0-nightly.20230323": "113.0.5668.0",
+	"25.0.0-nightly.20230324": "113.0.5670.0",
+	"25.0.0-nightly.20230327": "113.0.5670.0",
+	"25.0.0-nightly.20230328": "113.0.5670.0",
+	"25.0.0-nightly.20230329": "113.0.5670.0",
+	"25.0.0-nightly.20230330": "113.0.5670.0",
+	"25.0.0-nightly.20230331": "114.0.5684.0",
+	"25.0.0-nightly.20230403": "114.0.5684.0",
+	"25.0.0-nightly.20230404": "114.0.5692.0",
+	"25.0.0-nightly.20230405": "114.0.5694.0",
+	"25.0.0": "114.0.5735.45",
+	"25.0.1": "114.0.5735.45",
+	"25.1.0": "114.0.5735.106",
+	"25.1.1": "114.0.5735.106",
+	"25.2.0": "114.0.5735.134",
+	"25.3.0": "114.0.5735.199",
+	"25.3.1": "114.0.5735.243",
+	"25.3.2": "114.0.5735.248",
+	"25.4.0": "114.0.5735.248",
+	"25.5.0": "114.0.5735.289",
+	"25.6.0": "114.0.5735.289",
+	"25.7.0": "114.0.5735.289",
+	"25.8.0": "114.0.5735.289",
+	"25.8.1": "114.0.5735.289",
+	"25.8.2": "114.0.5735.289",
+	"25.8.3": "114.0.5735.289",
+	"25.8.4": "114.0.5735.289",
+	"25.9.0": "114.0.5735.289",
+	"25.9.1": "114.0.5735.289",
+	"25.9.2": "114.0.5735.289",
+	"25.9.3": "114.0.5735.289",
+	"25.9.4": "114.0.5735.289",
+	"25.9.5": "114.0.5735.289",
+	"25.9.6": "114.0.5735.289",
+	"25.9.7": "114.0.5735.289",
+	"25.9.8": "114.0.5735.289",
+	"26.0.0-alpha.1": "116.0.5791.0",
+	"26.0.0-alpha.2": "116.0.5791.0",
+	"26.0.0-alpha.3": "116.0.5791.0",
+	"26.0.0-alpha.4": "116.0.5791.0",
+	"26.0.0-alpha.5": "116.0.5791.0",
+	"26.0.0-alpha.6": "116.0.5815.0",
+	"26.0.0-alpha.7": "116.0.5831.0",
+	"26.0.0-alpha.8": "116.0.5845.0",
+	"26.0.0-beta.1": "116.0.5845.0",
+	"26.0.0-beta.2": "116.0.5845.14",
+	"26.0.0-beta.3": "116.0.5845.14",
+	"26.0.0-beta.4": "116.0.5845.14",
+	"26.0.0-beta.5": "116.0.5845.14",
+	"26.0.0-beta.6": "116.0.5845.14",
+	"26.0.0-beta.7": "116.0.5845.14",
+	"26.0.0-beta.8": "116.0.5845.42",
+	"26.0.0-beta.9": "116.0.5845.42",
+	"26.0.0-beta.10": "116.0.5845.49",
+	"26.0.0-beta.11": "116.0.5845.49",
+	"26.0.0-beta.12": "116.0.5845.62",
+	"26.0.0-nightly.20230406": "114.0.5694.0",
+	"26.0.0-nightly.20230407": "114.0.5694.0",
+	"26.0.0-nightly.20230410": "114.0.5694.0",
+	"26.0.0-nightly.20230411": "114.0.5694.0",
+	"26.0.0-nightly.20230412": "114.0.5708.0",
+	"26.0.0-nightly.20230413": "114.0.5710.0",
+	"26.0.0-nightly.20230414": "114.0.5710.0",
+	"26.0.0-nightly.20230417": "114.0.5710.0",
+	"26.0.0-nightly.20230418": "114.0.5715.0",
+	"26.0.0-nightly.20230421": "114.0.5719.0",
+	"26.0.0-nightly.20230424": "114.0.5719.0",
+	"26.0.0-nightly.20230425": "114.0.5719.0",
+	"26.0.0-nightly.20230426": "114.0.5719.0",
+	"26.0.0-nightly.20230427": "114.0.5719.0",
+	"26.0.0-nightly.20230428": "114.0.5719.0",
+	"26.0.0-nightly.20230501": "114.0.5719.0",
+	"26.0.0-nightly.20230502": "114.0.5719.0",
+	"26.0.0-nightly.20230503": "114.0.5719.0",
+	"26.0.0-nightly.20230504": "114.0.5719.0",
+	"26.0.0-nightly.20230505": "114.0.5719.0",
+	"26.0.0-nightly.20230508": "114.0.5719.0",
+	"26.0.0-nightly.20230509": "114.0.5719.0",
+	"26.0.0-nightly.20230510": "114.0.5719.0",
+	"26.0.0-nightly.20230511": "115.0.5760.0",
+	"26.0.0-nightly.20230512": "115.0.5760.0",
+	"26.0.0-nightly.20230515": "115.0.5760.0",
+	"26.0.0-nightly.20230516": "115.0.5760.0",
+	"26.0.0-nightly.20230517": "115.0.5760.0",
+	"26.0.0-nightly.20230518": "115.0.5760.0",
+	"26.0.0-nightly.20230519": "115.0.5760.0",
+	"26.0.0-nightly.20230522": "115.0.5760.0",
+	"26.0.0-nightly.20230523": "115.0.5760.0",
+	"26.0.0-nightly.20230524": "115.0.5786.0",
+	"26.0.0-nightly.20230525": "115.0.5790.0",
+	"26.0.0-nightly.20230526": "116.0.5791.0",
+	"26.0.0-nightly.20230529": "116.0.5791.0",
+	"26.0.0-nightly.20230530": "116.0.5791.0",
+	"26.0.0-nightly.20230531": "116.0.5791.0",
+	"26.0.0": "116.0.5845.82",
+	"26.1.0": "116.0.5845.97",
+	"26.2.0": "116.0.5845.179",
+	"26.2.1": "116.0.5845.188",
+	"26.2.2": "116.0.5845.190",
+	"26.2.3": "116.0.5845.190",
+	"26.2.4": "116.0.5845.190",
+	"26.3.0": "116.0.5845.228",
+	"26.4.0": "116.0.5845.228",
+	"26.4.1": "116.0.5845.228",
+	"26.4.2": "116.0.5845.228",
+	"26.4.3": "116.0.5845.228",
+	"26.5.0": "116.0.5845.228",
+	"26.6.0": "116.0.5845.228",
+	"26.6.1": "116.0.5845.228",
+	"26.6.2": "116.0.5845.228",
+	"26.6.3": "116.0.5845.228",
+	"27.0.0-alpha.1": "118.0.5949.0",
+	"27.0.0-alpha.2": "118.0.5949.0",
+	"27.0.0-alpha.3": "118.0.5949.0",
+	"27.0.0-alpha.4": "118.0.5949.0",
+	"27.0.0-alpha.5": "118.0.5949.0",
+	"27.0.0-alpha.6": "118.0.5949.0",
+	"27.0.0-beta.1": "118.0.5993.5",
+	"27.0.0-beta.2": "118.0.5993.5",
+	"27.0.0-beta.3": "118.0.5993.5",
+	"27.0.0-beta.4": "118.0.5993.11",
+	"27.0.0-beta.5": "118.0.5993.18",
+	"27.0.0-beta.6": "118.0.5993.18",
+	"27.0.0-beta.7": "118.0.5993.18",
+	"27.0.0-beta.8": "118.0.5993.18",
+	"27.0.0-beta.9": "118.0.5993.18",
+	"27.0.0-nightly.20230601": "116.0.5791.0",
+	"27.0.0-nightly.20230602": "116.0.5791.0",
+	"27.0.0-nightly.20230605": "116.0.5791.0",
+	"27.0.0-nightly.20230606": "116.0.5791.0",
+	"27.0.0-nightly.20230607": "116.0.5791.0",
+	"27.0.0-nightly.20230609": "116.0.5791.0",
+	"27.0.0-nightly.20230612": "116.0.5815.0",
+	"27.0.0-nightly.20230613": "116.0.5815.0",
+	"27.0.0-nightly.20230614": "116.0.5829.0",
+	"27.0.0-nightly.20230615": "116.0.5831.0",
+	"27.0.0-nightly.20230616": "116.0.5833.0",
+	"27.0.0-nightly.20230619": "116.0.5833.0",
+	"27.0.0-nightly.20230620": "116.0.5833.0",
+	"27.0.0-nightly.20230621": "116.0.5833.0",
+	"27.0.0-nightly.20230622": "116.0.5845.0",
+	"27.0.0-nightly.20230623": "116.0.5845.0",
+	"27.0.0-nightly.20230626": "116.0.5845.0",
+	"27.0.0-nightly.20230627": "116.0.5845.0",
+	"27.0.0-nightly.20230628": "116.0.5845.0",
+	"27.0.0-nightly.20230629": "116.0.5845.0",
+	"27.0.0-nightly.20230630": "116.0.5845.0",
+	"27.0.0-nightly.20230703": "117.0.5852.0",
+	"27.0.0-nightly.20230704": "117.0.5852.0",
+	"27.0.0-nightly.20230705": "117.0.5852.0",
+	"27.0.0-nightly.20230706": "117.0.5852.0",
+	"27.0.0-nightly.20230707": "117.0.5852.0",
+	"27.0.0-nightly.20230710": "117.0.5852.0",
+	"27.0.0-nightly.20230711": "117.0.5852.0",
+	"27.0.0-nightly.20230712": "117.0.5852.0",
+	"27.0.0-nightly.20230713": "117.0.5852.0",
+	"27.0.0-nightly.20230714": "117.0.5852.0",
+	"27.0.0-nightly.20230717": "117.0.5884.1",
+	"27.0.0-nightly.20230718": "117.0.5884.1",
+	"27.0.0-nightly.20230719": "117.0.5892.0",
+	"27.0.0-nightly.20230720": "117.0.5897.0",
+	"27.0.0-nightly.20230721": "117.0.5897.0",
+	"27.0.0-nightly.20230724": "117.0.5897.0",
+	"27.0.0-nightly.20230725": "117.0.5897.0",
+	"27.0.0-nightly.20230726": "117.0.5897.0",
+	"27.0.0-nightly.20230727": "117.0.5897.0",
+	"27.0.0-nightly.20230728": "117.0.5897.0",
+	"27.0.0-nightly.20230731": "117.0.5897.0",
+	"27.0.0-nightly.20230801": "117.0.5911.0",
+	"27.0.0-nightly.20230802": "117.0.5911.0",
+	"27.0.0-nightly.20230803": "117.0.5911.0",
+	"27.0.0-nightly.20230804": "117.0.5921.0",
+	"27.0.0-nightly.20230807": "117.0.5921.0",
+	"27.0.0-nightly.20230808": "117.0.5921.0",
+	"27.0.0-nightly.20230814": "117.0.5921.0",
+	"27.0.0-nightly.20230815": "117.0.5921.0",
+	"27.0.0-nightly.20230816": "118.0.5949.0",
+	"27.0.0": "118.0.5993.54",
+	"27.0.1": "118.0.5993.89",
+	"27.0.2": "118.0.5993.89",
+	"27.0.3": "118.0.5993.120",
+	"27.0.4": "118.0.5993.129",
+	"27.1.0": "118.0.5993.144",
+	"27.1.2": "118.0.5993.144",
+	"27.1.3": "118.0.5993.159",
+	"27.2.0": "118.0.5993.159",
+	"28.0.0-alpha.1": "119.0.6045.0",
+	"28.0.0-alpha.2": "119.0.6045.0",
+	"28.0.0-alpha.3": "119.0.6045.21",
+	"28.0.0-alpha.4": "119.0.6045.21",
+	"28.0.0-alpha.5": "119.0.6045.33",
+	"28.0.0-alpha.6": "119.0.6045.33",
+	"28.0.0-alpha.7": "119.0.6045.33",
+	"28.0.0-beta.1": "119.0.6045.33",
+	"28.0.0-beta.2": "120.0.6099.0",
+	"28.0.0-beta.3": "120.0.6099.5",
+	"28.0.0-beta.4": "120.0.6099.5",
+	"28.0.0-beta.5": "120.0.6099.18",
+	"28.0.0-beta.6": "120.0.6099.18",
+	"28.0.0-beta.7": "120.0.6099.18",
+	"28.0.0-beta.8": "120.0.6099.18",
+	"28.0.0-beta.9": "120.0.6099.18",
+	"28.0.0-beta.10": "120.0.6099.18",
+	"28.0.0-beta.11": "120.0.6099.35",
+	"28.0.0-nightly.20230817": "118.0.5949.0",
+	"28.0.0-nightly.20230818": "118.0.5949.0",
+	"28.0.0-nightly.20230821": "118.0.5949.0",
+	"28.0.0-nightly.20230822": "118.0.5949.0",
+	"28.0.0-nightly.20230823": "118.0.5949.0",
+	"28.0.0-nightly.20230824": "118.0.5949.0",
+	"28.0.0-nightly.20230825": "118.0.5949.0",
+	"28.0.0-nightly.20230828": "118.0.5949.0",
+	"28.0.0-nightly.20230829": "118.0.5949.0",
+	"28.0.0-nightly.20230830": "118.0.5949.0",
+	"28.0.0-nightly.20230831": "118.0.5949.0",
+	"28.0.0-nightly.20230906": "118.0.5991.0",
+	"28.0.0-nightly.20230907": "118.0.5993.0",
+	"28.0.0-nightly.20230908": "118.0.5993.0",
+	"28.0.0-nightly.20230911": "118.0.5993.0",
+	"28.0.0-nightly.20230912": "118.0.5993.0",
+	"28.0.0-nightly.20230913": "118.0.5993.0",
+	"28.0.0-nightly.20230914": "118.0.5993.0",
+	"28.0.0-nightly.20230915": "118.0.5993.0",
+	"28.0.0-nightly.20230919": "119.0.6006.0",
+	"28.0.0-nightly.20230920": "119.0.6017.0",
+	"28.0.0-nightly.20230921": "119.0.6019.2",
+	"28.0.0-nightly.20230925": "119.0.6019.2",
+	"28.0.0-nightly.20230926": "119.0.6019.2",
+	"28.0.0-nightly.20230927": "119.0.6019.2",
+	"28.0.0-nightly.20230928": "119.0.6019.2",
+	"28.0.0-nightly.20230929": "119.0.6029.0",
+	"28.0.0-nightly.20231002": "119.0.6029.0",
+	"28.0.0-nightly.20231003": "119.0.6043.0",
+	"28.0.0-nightly.20231004": "119.0.6043.0",
+	"28.0.0-nightly.20231005": "119.0.6043.0",
+	"28.0.0-nightly.20231006": "119.0.6045.0",
+	"28.0.0-nightly.20231009": "119.0.6045.0",
+	"28.0.0-nightly.20231010": "119.0.6045.0",
+	"28.0.0-nightly.20231011": "119.0.6045.0",
+	"28.0.0": "120.0.6099.56",
+	"28.1.0": "120.0.6099.109",
+	"29.0.0-alpha.1": "121.0.6147.0",
+	"29.0.0-alpha.2": "121.0.6147.0",
+	"29.0.0-alpha.3": "121.0.6147.0",
+	"29.0.0-alpha.4": "121.0.6159.0",
+	"29.0.0-alpha.5": "121.0.6159.0",
+	"29.0.0-nightly.20231012": "119.0.6045.0",
+	"29.0.0-nightly.20231013": "119.0.6045.0",
+	"29.0.0-nightly.20231016": "119.0.6045.0",
+	"29.0.0-nightly.20231017": "119.0.6045.0",
+	"29.0.0-nightly.20231018": "119.0.6045.0",
+	"29.0.0-nightly.20231019": "119.0.6045.0",
+	"29.0.0-nightly.20231020": "119.0.6045.0",
+	"29.0.0-nightly.20231023": "119.0.6045.0",
+	"29.0.0-nightly.20231024": "119.0.6045.0",
+	"29.0.0-nightly.20231025": "120.0.6078.0",
+	"29.0.0-nightly.20231026": "120.0.6078.0",
+	"29.0.0-nightly.20231027": "120.0.6078.0",
+	"29.0.0-nightly.20231030": "120.0.6078.0",
+	"29.0.0-nightly.20231031": "120.0.6078.0",
+	"29.0.0-nightly.20231101": "120.0.6078.0",
+	"29.0.0-nightly.20231102": "121.0.6100.0",
+	"29.0.0-nightly.20231103": "121.0.6100.0",
+	"29.0.0-nightly.20231106": "121.0.6104.0",
+	"29.0.0-nightly.20231107": "121.0.6110.0",
+	"29.0.0-nightly.20231108": "121.0.6110.0",
+	"29.0.0-nightly.20231109": "121.0.6110.0",
+	"29.0.0-nightly.20231110": "121.0.6110.0",
+	"29.0.0-nightly.20231113": "121.0.6110.0",
+	"29.0.0-nightly.20231114": "121.0.6110.0",
+	"29.0.0-nightly.20231115": "121.0.6116.0",
+	"29.0.0-nightly.20231116": "121.0.6116.0",
+	"29.0.0-nightly.20231117": "121.0.6116.0",
+	"29.0.0-nightly.20231120": "121.0.6116.0",
+	"29.0.0-nightly.20231121": "121.0.6116.0",
+	"29.0.0-nightly.20231122": "121.0.6116.0",
+	"29.0.0-nightly.20231123": "121.0.6116.0",
+	"29.0.0-nightly.20231124": "121.0.6116.0",
+	"29.0.0-nightly.20231127": "121.0.6116.0",
+	"29.0.0-nightly.20231128": "121.0.6116.0",
+	"29.0.0-nightly.20231129": "121.0.6147.0",
+	"29.0.0-nightly.20231130": "121.0.6147.0",
+	"29.0.0-nightly.20231201": "121.0.6147.0",
+	"29.0.0-nightly.20231204": "121.0.6147.0",
+	"29.0.0-nightly.20231205": "121.0.6147.0",
+	"29.0.0-nightly.20231206": "121.0.6147.0",
+	"30.0.0-nightly.20231207": "121.0.6147.0",
+	"30.0.0-nightly.20231208": "121.0.6147.0",
+	"30.0.0-nightly.20231211": "121.0.6147.0",
+	"30.0.0-nightly.20231212": "121.0.6159.0",
+	"30.0.0-nightly.20231213": "121.0.6159.0",
+	"30.0.0-nightly.20231214": "121.0.6159.0",
+	"30.0.0-nightly.20231215": "121.0.6159.0",
+	"30.0.0-nightly.20231218": "121.0.6159.0"
 };
\ No newline at end of file
